==> chromium_81.0.4044.62.orig.tar.xz: chromium-81.0.4044.62/chrome/browser/ui/views/safe_browsing/prompt_for_scanning_modal_dialog.h <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_VIEWS_SAFE_BROWSING_PROMPT_FOR_SCANNING_MODAL_DIALOG_H_
#define CHROME_BROWSER_UI_VIEWS_SAFE_BROWSING_PROMPT_FOR_SCANNING_MODAL_DIALOG_H_

#include "base/callback.h"
#include "base/callback_forward.h"
#include "base/timer/timer.h"
#include "ui/base/ui_base_types.h"
#include "ui/views/controls/button/button.h"
#include "ui/views/controls/styled_label.h"
#include "ui/views/controls/styled_label_listener.h"
#include "ui/views/window/dialog_delegate.h"

namespace content {
class WebContents;
}

namespace safe_browsing {

// A tab modal dialog that provides more information to the user about the
// prompt for deep scanning.
class PromptForScanningModalDialog : public views::DialogDelegateView,
                                     public views::ButtonListener,
                                     public views::StyledLabelListener {
 public:
  // Show this dialog for the given |web_contents|.
  static void ShowForWebContents(content::WebContents* web_contents,
                                 base::OnceClosure accept_callback,
                                 base::OnceClosure open_now_callback);

  // Create a PromptForScanningModalDialog attached to |web_contents|. The
  // dialog will call |accept_callback| if the user accepts the prompt.
  PromptForScanningModalDialog(content::WebContents* web_contents,
                               base::OnceClosure accept_callback,
                               base::OnceClosure open_now_callback);
  PromptForScanningModalDialog(const PromptForScanningModalDialog&) = delete;
  PromptForScanningModalDialog& operator=(const PromptForScanningModalDialog&) =
      delete;
  ~PromptForScanningModalDialog() override;

  // views::DialogDelegate implementation:
  bool IsDialogButtonEnabled(ui::DialogButton button) const override;
  bool Cancel() override;
  bool Accept() override;
  bool ShouldShowCloseButton() const override;

  // views::WidgetDelegate implementation:
  base::string16 GetWindowTitle() const override;
  ui::ModalType GetModalType() const override;

  // views::ButtonListener implementation:
  void ButtonPressed(views::Button* sender, const ui::Event& event) override;

  // views::StyledLabelListener implementation:
  void StyledLabelLinkClicked(views::StyledLabel* label,
                              const gfx::Range& range,
                              int event_flags) override;

 private:
  // The WebContents this dialog is attached to. This is unowned.
  content::WebContents* web_contents_;

  // The open now button for this dialog. The pointer is unowned, but this is a
  // child View of this dialog's View, so it has the same lifetime.
  views::Button* open_now_button_;

  // The callbacks to trigger on each way the dialog is resolved.
  base::OnceClosure accept_callback_;
  base::OnceClosure open_now_callback_;
};

}  // namespace safe_browsing

#endif  // CHROME_BROWSER_UI_VIEWS_SAFE_BROWSING_PROMPT_FOR_SCANNING_MODAL_DIALOG_H_

==> chromium_88.0.4324.96.orig.tar.xz: chromium-88.0.4324.96/chrome/browser/ui/views/safe_browsing/prompt_for_scanning_modal_dialog.h <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_VIEWS_SAFE_BROWSING_PROMPT_FOR_SCANNING_MODAL_DIALOG_H_
#define CHROME_BROWSER_UI_VIEWS_SAFE_BROWSING_PROMPT_FOR_SCANNING_MODAL_DIALOG_H_

#include "base/callback.h"
#include "base/callback_forward.h"
#include "base/timer/timer.h"
#include "ui/base/ui_base_types.h"
#include "ui/views/controls/styled_label.h"
#include "ui/views/window/dialog_delegate.h"

namespace content {
class WebContents;
}

namespace safe_browsing {

// A tab modal dialog that provides more information to the user about the
// prompt for deep scanning.
class PromptForScanningModalDialog : public views::DialogDelegateView {
 public:
  // Show this dialog for the given |web_contents|.
  static void ShowForWebContents(content::WebContents* web_contents,
                                 const base::string16& filename,
                                 base::OnceClosure accept_callback,
                                 base::OnceClosure open_now_callback);

  // Create a PromptForScanningModalDialog attached to |web_contents|. The
  // dialog will call |accept_callback| if the user accepts the prompt.
  PromptForScanningModalDialog(content::WebContents* web_contents,
                               const base::string16& filename,
                               base::OnceClosure accept_callback,
                               base::OnceClosure open_now_callback);
  PromptForScanningModalDialog(const PromptForScanningModalDialog&) = delete;
  PromptForScanningModalDialog& operator=(const PromptForScanningModalDialog&) =
      delete;
  ~PromptForScanningModalDialog() override;

  // views::DialogDelegate implementation:
  bool IsDialogButtonEnabled(ui::DialogButton button) const override;
  bool ShouldShowCloseButton() const override;

  // views::WidgetDelegate implementation:
  ui::ModalType GetModalType() const override;

 private:
  base::OnceClosure open_now_callback_;
};

}  // namespace safe_browsing

#endif  // CHROME_BROWSER_UI_VIEWS_SAFE_BROWSING_PROMPT_FOR_SCANNING_MODAL_DIALOG_H_
